[![Documentation Status](https://readthedocs.org/projects/ansicolortags/badge/?version=latest)](https://cpgtools.readthedocs.io/en/latest/)
[![GitHub issues](https://img.shields.io/github/issues/liguowang/cpgtools)](https://github.com/liguowang/cpgtools/issues)
[![GitHub license](https://img.shields.io/github/license/liguowang/cpgtools)](https://github.com/liguowang/cpgtools/blob/master/LICENSE.txt)

### Install CpGtools using [pip](https://pip.pypa.io/en/stable/)

 `$ pip install cpgtools`
 or
 `$ pip install git+https://github.com/liguowang/cpgtools.git`

### Upgrade

 `$ pip install cpgtools --upgrade`

### Uninstall
 `pip -y uninstall cpgtools`

### Documentation

https://cpgtools.readthedocs.io/en/latest/
